Crate bevy_sun_move

Crate bevy_sun_move 

Modules

random_stars

Structs

SkyCenter
SunMovePlugin
TimedSkyConfig
TypedSunMovePlugin

Constants

DEGREES_TO_RADIANS
RADIANS_TO_DEGREES

Traits

ISunTime

Functions

calculate_latitude_yearfraction
Calculates required latitude and year fraction to achieve a specific day/night duration ratio and maximum sun height (noon altitude) for a given planet tilt.
calculate_sun_direction
Calculates the sun’s direction vector in the observer’s local coordinate frame (Y up, X east, Z north). This vector points from the observer towards the sun.